@@ -24,7 +24,7 @@ NULL
     input[, "ordering" := .I]
   } 
   lito_tbl[input] %>%
-    .[, lito := pminV(pmaxIPnum0(max_lito - (income - min_bracket) * lito_taper),
+    .[, lito := pminV(pmax0(max_lito - (income - min_bracket) * lito_taper),
                       max_lito)] %>%
     setorderv("ordering") %>%
     .subset2("lito")
@@ -38,7 +38,7 @@ lito <- function(income,
                  lito_taper = 0.015, 
                  min_bracket = 37000){
   if (length(max_lito) == 1L){
-    pminC(pmaxIPnum0(max_lito - (income - min_bracket) * lito_taper),
+    pminC(pmax0(max_lito - (income - min_bracket) * lito_taper),
           max_lito)
   } else {
     # Need to guard against unequal length vectors passed to pminV. In particular
