@@ -203,6 +203,10 @@ hasntName <- function(x, name) {
   match(name, names(x), nomatch = 0L) == 0L
 }
 
+haveNames <- function(x, noms) {
+  all(noms %in% names(x))
+}
+
 age2age_range <- function(age) {
   pmax.int(pmin.int(11L - {(age - 15L) %/% 5L}, 11L), 0L)
 }
