@@ -69,14 +69,12 @@ test_that("upper and lower series produce higher and lower forecasts", {
 })
 
 test_that("lf_inflator returns known results", {
-  skip_on_cran()
-  skip("lf inflator using trend")
+  skip("Trend has been withdrawn")
   expect_equal(lf_inflator(from_date = "1981-01-01", to_date = "1981-02-01"), 1.00124729250057, tol = 0.001)
 })
 
 test_that("lf_inflator returns long", {
-  skip_on_cran()
-  skip("lf inflator using trend")
+  skip("Trend has been withdrawn")
   expect_equal(round(lf_inflator_fy(labour_force = c(1, 2), from_fy = "2010-11", to_fy = "2012-13"), 3),
                round(c(1.02691290641353, 2.05382581282705), 3), 
                tol = 0.002)
@@ -120,7 +118,7 @@ test_that("Custom lf series", {
 })
 
 test_that("ABS connection", {
-  skip("ABS not available")
+  skip("ABS not accepting connections")
   skip_if_not_installed("rsdmx")
   skip_if_not(packageVersion("rsdmx") >= package_version("0.5.10"))
   skip_on_cran()
@@ -132,7 +130,6 @@ test_that("ABS connection", {
   expect_equal(internal_ans, external_ans, tol = 0.0005)
   
   internal_ans <- lf_inflator(from_date = "2009-06-30", to_date = "2014-06-30")
-  
   external_ans <- lf_inflator(from_date = "2009-06-30", to_date = "2014-06-30",
                               useABSConnection = TRUE)
   
